SmartPluginRegistry class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
customValidators
→ Map<
String, ValidatorFunction> -
final
-
dataProviders
→ Map<
String, DataProviderFunction> -
final
-
fieldBuilders
→ Map<
String, FieldBuilderFunction> -
final
Static Methods
-
registerDataProvider(
String name, DataProviderFunction provider) → void -
registerFieldBuilder(
String type, FieldBuilderFunction builder) → void -
registerValidator(
String name, ValidatorFunction validator) → void